An XML External Entity attack is a type of attack against an
application that parses XML input.

This attack occurs when XML input
containing a reference to an external entity is processed by a weakly
configured XML parser.

This attack may lead to the disclosure of
confidential data, denial of service, port scanning from the
perspective of the machine where the parser is located, and other
system impacts.